@@ -1,6 +1,6 @@
 #  gcompris - module_boards.py
 #
-# Copyright (C) 2005 Yves Combe
+# Copyright (C) 2005, 2008 Yves Combe
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
-import gnomecanvas
+import goocanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
@@ -27,7 +27,15 @@ from gcompris import gcompris_gettext as _
 import sys;
 
 # Database
-from pysqlite2 import dbapi2 as sqlite
+try:
+  from sqlite3 import dbapi2 as sqlite # python 2.5
+except:
+  try:
+    from pysqlite2 import dbapi2 as sqlite
+  except:
+    print 'This program requires pysqlite2\n',\
+        'http://initd.org/tracker/pysqlite/'
+    sys.exit(1)
 
 import module
 import board_list
@@ -35,9 +43,9 @@ import board_list
 class Boards(module.Module):
   """Administrating GCompris Boards"""
 
+  already_loaded = False
 
   def __init__(self, canvas):
-    print("Gcompris_administration __init__ boards panel.")
     module.Module.__init__(self, canvas, "boards", _("Boards"))
 
   # Return the position it must have in the administration menu
@@ -46,45 +54,53 @@ class Boards(module.Module):
     return 3
 
   def start(self, area):
-    print "starting boards panel"
-
-    # Create our rootitem. We put each canvas item in it so at the end we
-    # only have to kill it. The canvas deletes all the items it contains automaticaly.
-
-    self.rootitem = self.canvas.add(
-        gnomecanvas.CanvasGroup,
-        x=0.0,
-        y=0.0
-        )
-
-    module.Module.start(self)
-
     # Connect to our database
     self.con = sqlite.connect(gcompris.get_database())
     self.cur = self.con.cursor()
 
-    frame = gtk.Frame(_("Boards"))
-    frame.show()
+    if Boards.already_loaded:
+      self.rootitem.props.visibility = goocanvas.ITEM_VISIBLE
+      self.boardList.show(self.con, self.cur)
+      return
 
-    self.rootitem.add(
-      gnomecanvas.CanvasWidget,
-      widget=frame,
+    Boards.already_loaded = True
+
+    # Create our rootitem. We put each canvas item in it so at the end we
+    # only have to kill it. The canvas deletes all the items it contains automaticaly.
+
+    self.rootitem = goocanvas.Group(
+      parent = self.canvas,
+      )
+
+    module.Module.start(self)
+
+    self.frame = gtk.Frame(_("Boards"))
+    self.frame.show()
+
+    goocanvas.Widget(
+      parent = self.rootitem,
+      widget=self.frame,
       x=area[0]+self.module_panel_ofset,
       y=area[1]+self.module_panel_ofset,
       width=area[2]-area[0]-2*self.module_panel_ofset,
       height=area[3]-area[1]-2*self.module_panel_ofset,
-      anchor=gtk.ANCHOR_NW,
-      size_pixels=False)
+      anchor=gtk.ANCHOR_NW)
 
-    board_list.Board_list(self.con, self.cur,
-                          frame)
+    # Get default pofile id.
+    self.cur.execute('SELECT profile_id FROM informations;')
+    self.con.commit()
+    default_profile_id = self.cur.fetchall()[0][0]
+
+    self.boardList = board_list.Board_list(self.con, self.cur,
+                                           self.frame, default_profile_id)
+    self.boardList.init()
 
   def stop(self):
-    print "stopping boards panel"
     module.Module.stop(self)
 
-    # Remove the root item removes all the others inside it
-    self.rootitem.destroy()
+    # This module is slow to start, we just hide it
+    self.rootitem.props.visibility = goocanvas.ITEM_INVISIBLE
+    self.boardList.hide()
 
     # Close the database
     self.cur.close()
