@@ -30,7 +30,7 @@ import os
 import tempfile
 
 # Set to True to debug
-debug = False
+debug = True
 
 from gcompris import gcompris_gettext as _
 
@@ -86,10 +86,10 @@ class Gcompris_electric:
     # You can provide a gnucap binary in python_plugin_dir.
     #
     for binary in (os.environ.get('GNUCAP', ''),
+                   "gnucap.exe",
                    os.path.join(gcompris.PYTHON_PLUGIN_DIR, 'bin', 'gnucap'),
                    "/usr/bin/gnucap",
                    "/usr/local/bin/gnucap",
-                   "gnucap.exe",
 		   os.path.join(gcompris.DATA_DIR, '..' , '..', '..', 'bin', 'gnucap')):
       if(os.path.exists(binary)):
         self.gnucap_binary = binary
@@ -288,6 +288,7 @@ class Gcompris_electric:
                        (Resistor, 1000),
                        (Switch, None),
                        (Connection, None),
+                       (RedLed, None),
                        (Diode, None),
                        )
 
@@ -317,6 +318,7 @@ class Gcompris_electric:
       self.gnucap_timer = 0
       return
 
+    self.gnucap_timer = 0
     connected = False
     for component in self.components:
       if component.is_connected():
@@ -383,7 +385,6 @@ class Gcompris_electric:
     results = output.close()
     if results:
       print('Failed to run gnugap with error ', results)
-      self.gnucap_timer = 0
       return
 
     values = []
@@ -428,7 +429,6 @@ class Gcompris_electric:
 
 
     if not debug: os.remove(filename)
-    self.gnucap_timer = 0
 
   # Convert a gnucap value back in a regular number
   # Return a float value
@@ -495,17 +495,21 @@ class Wire:
     #numbered sequentially.
     counter = 1
     connection = {}
-    colors = [ 0xdfc766FFL,
-               0xdf9766FFL,
-               0xdf667dFFL,
-               0xdf66bcFFL,
-               0xc466dfFFL,
-               0x9c66dfFFL,
-               0xA4FFB3FFL,
-               0x6666dfFFL,
-               0x669fdfFFL,
-               0x66df6cFFL,
-               0x66dfd8FFL ]
+    colors = [
+      0x000573FFL,
+      0x087008FFL,
+      0x0a62e5FFL,
+      0x33666cFFL,
+      0x669fdfFFL,
+      0x73004cFFL,
+      0x9c66dfFFL,
+      0xAA6633FFL,
+      0xCC3366FFL,
+      0xDD33CCFFL,
+      0xc466dfFFL,
+      0xdf66bcFFL,
+      0xe03f1bFFL
+      ]
 
     def __init__(self, electric, source_node, x1, y1, x2, y2):
       self.electric = electric
@@ -521,9 +525,8 @@ class Wire:
         parent = self.rootitem,
         points = goocanvas.Points([(self.x1, self.y1),
                                    (self.x2, self.y2)]),
-        stroke_color_rgba = 0xFF0000FFL,
         line_cap = cairo.LINE_CAP_ROUND,
-        line_width=5.0
+        line_width=7.0
         )
       self.wire_item.connect("button_press_event", self.delete_wire, self)
       self.wire_id = -1
@@ -555,6 +558,9 @@ class Wire:
 
         Wire.connection[node] = self
 
+      # Colorize the wire
+      self.wire_item.set_properties(stroke_color_rgba = \
+                                      Wire.colors[self.wire_id % len(Wire.colors)])
       if debug: print "WIRE_ID = %d" %self.wire_id
 
     def set_wire_id(self, id):
@@ -564,9 +570,6 @@ class Wire:
       if(self.source_node):
         self.source_node.renumber_wire(self, id)
 
-      # Colorize the wire
-      self.wire_item.set_properties(fill_color_rgba = Wire.colors[id % len(Wire.colors)])
-
     def get_wire_id(self):
       return self.wire_id
 
@@ -586,9 +589,6 @@ class Wire:
       self.target_node = node
       self._add_connection(node)
 
-      # Colorize the wire
-      self.wire_item.set_properties(fill_color_rgba = Wire.colors[self.wire_id % len(Wire.colors)])
-
     # Move wire. In fact, the attached component are moved and THEY
     # move the wire
     def move_all_wire(self, x, y):
@@ -781,7 +781,7 @@ class Component(object):
           parent = self.comp_rootitem,
         x = self.item_values_x,
         y = self.item_values_y,
-        font = "Sans 8",
+        font = "Sans 7",
         text = "",
         fill_color = "white",
         anchor = gtk.ANCHOR_CENTER
@@ -1008,13 +1008,66 @@ class Diode(Component):
     # Idealized diode: ~0V treshold voltage. Characteristic graph
     # passes through the two points (10 mV, 10 mA) and (20 mV, 2000
     # mA) => N  = 0.072 IS = 5x10-5 A
-    model = ".model  ddd  d  ( is= 50.u  rs= 0.  n= 0.072  tt= 0.  cjo= 1.p  vj= 1.  m= 0.5\n"
-    model += "+ eg= 1.11  xti= 3.  kf= 0.  af= 1.  fc= 0.5  bv= 0.  ibv= 0.001 )\n"
+    model = ".model  ddd  d  ( is= 50.u  rs= 0.  n= 0.072  tt= 0.  cjo= 1.p  vj= 1.  m= 0.5"
+    model += " eg= 1.11  xti= 3.  kf= 0.  af= 1.  fc= 0.5  bv= 0.  ibv= 0.001 )\n"
 
     gnucap = []
     gnucap = super(Diode, self).to_gnucap(model)
     return gnucap
 
+# ----------------------------------------
+# DIODE
+#
+#
+class RedLed(Component):
+  image = "electric/red_led_off.png"
+  icon  = "electric/red_led_icon.png"
+  def __init__(self, electric,
+               x, y, dummy):
+    super(RedLed, self).__init__(electric,
+                                "D",
+                                "led1 1.",
+                               self.image,
+                               [Node("electric/connect.png", "A", -10, 45),
+                                Node("electric/connect.png", "B", 30, 45)])
+
+    # Overide some values
+    self.item_values_x = 50
+    self.item_values_y = 12
+
+    self.move(x, y)
+    self.show()
+
+  # Return the gnucap definition for this component
+  # Here we just add the diode model
+  def to_gnucap(self, model):
+    # Our 'ddd' Diode model
+    # Idealized diode: ~0V treshold voltage. Characteristic graph
+    # passes through the two points (10 mV, 10 mA) and (20 mV, 2000
+    # mA) => N  = 0.072 IS = 5x10-5 A
+    model = ".model led1 d ( is=93.p rs=42M n=4.61 bv=4 ibv=10U"
+    model += " cjo=2.97P vj=.75 M=.333 TT=4.32U )\n"
+
+    gnucap = []
+    gnucap = super(RedLed, self).to_gnucap(model)
+    return gnucap
+
+  # Return False if we need more value to complete our component
+  # This is usefull in case where one Component is made of several gnucap component
+  def set_voltage_intensity(self, valid_value, voltage, intensity):
+    self.voltage = voltage
+    self.intensity = intensity
+    power = voltage * intensity
+    if debug: print "Led V=%f I=%f P=%f" %(self.voltage, self.intensity, power)
+    if power > 0.01:
+      pixmap = gcompris.utils.load_pixmap("electric/red_led_on.png")
+    else:
+      pixmap = gcompris.utils.load_pixmap("electric/red_led_off.png")
+    self.component_item.set_properties(pixbuf = pixmap)
+    # Never show values
+    self.item_values.props.visibility = goocanvas.ITEM_INVISIBLE
+    return True
+
 # ----------------------------------------
 # SWITCH
 #
@@ -1508,8 +1561,8 @@ class Bulb(Component):
     # Resistor value to infinite and ask for a circuit recalc
     if image_index == 11:
       self.gnucap_value = self.resistor_blown
-      self.electric.run_simulation()
       self.is_blown = True
+      self.electric.run_simulation()
 
     return True
 
@@ -1550,7 +1603,7 @@ class Battery(Component):
                                [Node("electric/connect.png", "A", 6, -35),
                                 Node("electric/connect.png", "B", 6, 120)])
     # Overide some values
-    self.item_values_x = 23
+    self.item_values_x = 24
     self.item_values_y = 70
 
     self.move(x, y)
@@ -1674,5 +1727,4 @@ class Selector:
     # ------------------------------------------------------------
 
 def stop_board():
-    gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
-
+  pass
